@@ -6,9 +6,12 @@ except ImportError:
     from urllib2 import urlopen, Request
 
 from collections import namedtuple
-
 import json
 
+from .bearing import Bearing
+from .point import Point
+
+
 Wind = namedtuple('Wind', ['direction', 'speed'])
 
 
@@ -48,8 +51,11 @@ class Boatd(object):
         print(content)
 
 
-class Boat(object):
-    '''A boat controlled by boatd'''
+class LegacyBoat(object):
+    '''
+    A boat controlled by boatd. This is the legacy boat interface for backwards
+    compatibility. Deprecated.
+    '''
 
     def __init__(self, boatd=None):
         if boatd is None:
@@ -94,6 +100,64 @@ class Boat(object):
         return content.get('result')
 
 
+class ConvenienceBoat(object):
+    '''A boat controlled by boatd'''
+
+    def __init__(self, boatd=None):
+        if boatd is None:
+            self.boatd = Boatd()
+        else:
+            self.boatd = boatd
+
+    @property
+    def heading(self):
+        '''Return the current heading of the boat in degrees'''
+        content = self.boatd.get('/boat')
+        return Bearing(float(content.get('heading')))
+
+    @property
+    def wind(self):
+        '''Return the direction of the wind in degrees'''
+        content = self.boatd.get('/wind')
+        return Wind(Bearing(content.get('direction')), content.get('speed'))
+
+    @property
+    def position(self):
+        '''Return a tuple in the form `(latitude, longitude)`'''
+        content = self.boatd.get('/boat')
+        lat, lon = content.get('position')
+        return Point(lat, lon)
+
+    @property
+    def version(self):
+        '''Return the version of boatd'''
+        content = self.boatd.get('/')
+        return content.get('boatd').get('version')
+
+    def rudder(self, angle):
+        '''Set the angle of the rudder to be `angle` degrees'''
+        request = self.boatd.post({'value': float(angle)}, '/rudder')
+        content = json.loads(request.read().decode('utf-8'))
+        return content.get('result')
+
+    def sail(self, angle):
+        '''Set the angle of the sail to `angle` degrees'''
+        request = self.boatd.post({'value': float(angle)}, '/sail')
+        content = json.loads(request.read().decode('utf-8'))
+        return content.get('result')
+
+
+def Boat(convenience=False, *args, **kwargs):
+    '''
+    Return a Boat instance. If ``convenience`` is True, return an instance of
+    ``ConvenienceBoat``, otherwise return ``LegacyBoat``.
+    '''
+    if convenience is True:
+        return ConvenienceBoat(*args, **kwargs)
+    else:
+        return LegacyBoat(*args, **kwargs)
+
+
 class Behaviour(object):
     def __init__(self, boatd=None):
         if boatd is None:
@@ -105,9 +169,16 @@ class Behaviour(object):
         return self.boatd.get('/behaviours')
 
     def list(self):
+        '''Return a list of the available behaviours to run.'''
         return list(self._get_behaviour_data().get('behaviours').keys())
 
     def start(self, name):
+        '''
+        End the current behaviour and run a named behaviour.
+
+        :param name: the name of the behaviour to run
+        :type name: str
+        '''
         d = self.boatd.post({'current': name}, endpoint='/behaviours')
         current = d.get('current')
         if current is not None:
@@ -116,6 +187,9 @@ class Behaviour(object):
             return 'no behaviour running'
 
     def stop(self):
+        '''
+        Stop the current behaviour.
+        '''
         self.start(None)
 
 
